.login_container {
  border: 1px solid #267D87;
  padding: 20px;
  margin: 20px;
}
.login_logo {
  display: block;
  margin-left: auto;
  margin-right: auto;
}

.login_content {
  margin: 10px 15px;
}

/* iPads (landscape) ----------- */
@media only screen and (min-device-width : 768px) and (max-device-width : 1024px) and (orientation : landscape) {
  .form_row input {
    width: 300px;
  }
}

@media (min-width:569px) { 
  .form_row label {
    display:inline-block;
  }
  .form_row input {
    display:inline-block;
  }
  .login_content {
      width: 60%;
      margin: 0px auto;
  }
}