<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd"> 
<html>
    <head>
        <meta http-equiv="content-type" content="text/html; charset=UTF-8">
        <meta name="viewport" content="width=device-width; initial-scale=1.0;">
        {% load i18n %}
        <title>{% block title %}{% trans "Mobile App Distribution" %}{% endblock %}</title>
        {% load staticfiles %}
        
        <link rel="stylesheet" href="{% static 'django_mobile_app_distribution/css/jquery.mobile-1.3.1.min.css' %}" />
        <script type="text/javascript" src="{% static 'django_mobile_app_distribution/js/jquery-1.9.1.min.js' %}"></script>
        <script type="text/javascript" src="{% static 'django_mobile_app_distribution/js/jquery.mobile-1.3.1.min.js' %}"></script>
        <link rel="stylesheet" href="{% static 'django_mobile_app_distribution/css/errors.css' %}" type="text/css" media="screen" />
        <link rel="stylesheet" href="{% static 'django_mobile_app_distribution/css/base.css' %}" type="text/css" media="screen" />
        <link rel="stylesheet" href="{% static 'django_mobile_app_distribution/css/forms.css' %}" type="text/css" media="screen" />
    </head>
    <body>
        {% block content %}{% endblock %}
    </body>
</html>