{% extends "django_mobile_app_distribution/base.html" %}
{% load i18n %}
{% load url from future %}
{% load staticfiles %}
{% block title %}{% trans "customer login" %}{% endblock %}
{% block content %}

<div class="login_container">
	<div>
		<img class="login_logo" src="{% static 'django_mobile_app_distribution/images/logo@2x.png' %}" width="180px" height="90px">	
	</div>
	<div class="login_content">
			<div>
				<form data-ajax="false" method="post" action="{% url 'django.contrib.auth.views.login' %}">{% csrf_token %}
					{{ form.username.label_tag }} {{ form.username }}
					{{ form.password.label_tag }} {{ form.password }}
					{% if form.errors %}
					<ul class="loginerror">
						<li>
							 {% trans "invalid login credentials" %}
						</li>
					</ul>
					{% endif %}
					<input type="submit" value="{% trans 'login' %}" />
					<input type="hidden" name="next" value="{{ next }}" />
				</form>
			</div>
	</div>
</div>
{% endblock %}
